View source: R/create_mcnodes.R
| create_mcnodes | R Documentation |
Creates Monte Carlo nodes (mcnodes) based on instructions provided in a configuration table (mctable) and input variables from a dataframe.
create_mcnodes(data, mctable = set_mctable(), envir = parent.frame())
data |
A data frame containing the input variables for creating Monte Carlo nodes |
mctable |
A configuration table specifying MC node definitions. Must contain columns:
|
envir |
Environment where MC nodes will be created (default: parent.frame()) |
No return value, creates MC nodes in the specified environment
create_mcnodes(data = imports_data, mctable = imports_mctable)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.