| eval_module | R Documentation |
Takes a set of Monte Carlo model expressions and evaluates them and creates an mcmodule containing results and metadata.
eval_module(
exp,
data,
param_names = NULL,
prev_mcmodule = NULL,
summary = FALSE,
mctable = set_mctable(),
data_keys = set_data_keys(),
match_keys = NULL,
keys = NULL,
overwrite_keys = NULL
)
exp |
Model expression or list of expressions to evaluate |
data |
Input data frame containing model parameters |
param_names |
Named vector for parameter renaming (optional) |
prev_mcmodule |
Previous module(s) for dependent calculations |
summary |
Logical; whether to calculate summary statistics |
mctable |
Reference table for mcnodes, defaults to set_mctable() |
data_keys |
Data structure and keys, defaults to set_data_keys() |
match_keys |
Keys to match prev_mcmodule mcnodes and data by |
keys |
Optional explicit keys for the input data (character vector) |
overwrite_keys |
Logical or NULL. If NULL (default) it becomes TRUE when data_keys is NULL or an empty list; otherwise FALSE. |
An mcmodule object containing data, expressions, and nodes
# Basic usage with single expression
eval_module(
exp = imports_exp,
data = imports_data,
mctable = imports_mctable,
data_keys = imports_data_keys
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.