| get_mcmodule_nodes | R Documentation |
Retrieves nodes from a Monte Carlo module and assigns them to the parent environment
get_mcmodule_nodes(mcmodule, mc_names = NULL, envir = parent.frame())
mcmodule |
An mcmodule or mcnode_list object |
mc_names |
Optional vector of node names to retrieve |
envir |
Environment where MC nodes will be created (default: parent.frame()) |
A subset of the node list containing requested nodes
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.