View source: R/get_node_list.R
| get_node_list | R Documentation |
Creates a list of nodes based on a given model expression, handling input, output, and previous nodes with their properties and relationships.
get_node_list(
exp,
param_names = NULL,
mctable = set_mctable(),
data_keys = set_data_keys(),
keys = NULL
)
exp |
An R expression containing model calculations |
param_names |
Optional named vector for parameter renaming |
mctable |
Reference table for mcnodes, defaults to set_mctable() |
data_keys |
Data structure and keys, defaults to set_data_keys() |
keys |
Optional explicit keys for the input data (character vector) |
A list of class "mcnode_list" containing node information
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.