| imports_data_keys | R Documentation |
A hierarchical data structure containing test sensitivity, animal import, and regional prevalence information, each with defined columns and keys.
imports_data_keys
A list with three components:
List containing column names for test sensitivity data and "pathogen" as key
List containing column names for animal import data and "origin" as key
List containing column names for prevalence data with "pathogen" and "origin" as keys
Simulated data for demonstration purposes
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.