Transforms an mcmodule into a list of matrices, with one matrix per variate. Each matrix has uncertainty simulations as rows and mcnodes as columns.
mcmodule_to_matrices(mcmodule, mc_names = NULL)A list of matrices (one per variate). Each matrix has uncertainty simulations as rows and mcnodes as columns.
(mcmodule object). Module to convert.
(character vector, optional). Node names to include. If NULL, includes all nodes. Default: NULL.