mc2d ObjectsConverts an mcmodule into one or more mc objects (from the mc2d package). Returns either one mc object per variate or a single mc object with all variates combined into the variability dimension.
mcmodule_to_mc(
mcmodule,
mc_names = NULL,
match = FALSE,
variates_as_nsv = FALSE
)If variates_as_nsv = FALSE, a list of mc objects (one per variate).
If variates_as_nsv = TRUE, a single mc object with all variates combined
into the variability dimension. Each mc object is compatible with mc2d
package functions.
(mcmodule object). Module to convert.
(character vector, optional). Node names to include. If NULL, includes all nodes. Default: NULL.
(logical, unused). Reserved for future functionality. Default: FALSE.
(logical). If TRUE, combine all variates into a single mc object by multiplying variates by uncertainty simulations in the variability dimension. If FALSE, return one mc object per variate. Default: FALSE.