View source: R/set_data_keys.R
| set_data_keys | R Documentation |
Manages a global data model by either setting new data keys or retrieving the current ones. The data model consists of named lists containing column names and their associated key columns.
set_data_keys(data_keys = NULL)
data_keys |
Optional list of lists. Each inner list must contain:
If NULL, returns the current data model. |
If data_keys = NULL: Returns the current global data model
If data_keys provided: Sets the new data model and returns invisibly
print(imports_data_keys)
set_data_keys(imports_data_keys)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.