Learn R Programming

mcmodule (version 1.2.0)

create_mcnodes: Create mcnodes from Data and Configuration Table

Description

Creates mcnodes based on mctable specifications and input data. Applies transformations and generates mcnodes in the calling environment.

Usage

create_mcnodes(data, mctable = set_mctable(), envir = parent.frame())

Value

NULL (invisibly). mcnodes created in envir.

Arguments

data

(data frame). Input data containing variables for mcnode creation.

mctable

(data frame). Configuration table with columns: mcnode, mc_func, transformation, from_variable.

envir

(environment, optional). Environment where nodes are created. Default: parent.frame().

Examples

Run this code
create_mcnodes(
  data = imports_data,
  mctable = imports_mctable
)

Run the code above in your browser using DataLab