powered by
Creates mcnodes based on mctable specifications and input data. Applies transformations and generates mcnodes in the calling environment.
create_mcnodes(data, mctable = set_mctable(), envir = parent.frame())
NULL (invisibly). mcnodes created in envir.
envir
(data frame). Input data containing variables for mcnode creation.
(data frame). Configuration table with columns: mcnode, mc_func, transformation, from_variable.
(environment, optional). Environment where nodes are created. Default: parent.frame().
create_mcnodes( data = imports_data, mctable = imports_mctable )
Run the code above in your browser using DataLab