| get_edge_table | R Documentation |
Creates a data frame containing edge relationships between nodes in a Monte Carlo module network. Each row represents a directed edge from one node to another.
get_edge_table(mcmodule, inputs = FALSE)
mcmodule |
An mcmodule object containing node relationships |
inputs |
Include non-node inputs: data-sets, data-frames and columns (optional) |
A data frame with columns node_from and node_to representing network edges
edge_table <- get_edge_table(imports_mcmodule)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.