Learn R Programming

mcmodule (version 1.2.0)

get_edge_table: Generate Edge Table for Network Visualisation

Description

Creates a data frame containing edge relationships between nodes in a Monte Carlo module network. Each row represents a directed edge from one node to another.

Usage

get_edge_table(mcmodule, inputs = FALSE)

Value

A data frame with columns node_from and node_to representing network edges.

Arguments

mcmodule

(mcmodule object). Module containing node relationships.

inputs

(logical). If TRUE, include non-node inputs (datasets, dataframes, and columns). Default: FALSE.

Examples

Run this code
edge_table <- get_edge_table(imports_mcmodule)

Run the code above in your browser using DataLab