mc_network: Create Interactive Network Visualisation
Description
Generates an interactive network visualisation using visNetwork library.
The visualisation includes interactive features for exploring model structure
and relationships.
Usage
mc_network(
mcmodule,
variate = 1,
color_pal = NULL,
color_by = NULL,
legend = FALSE,
inputs = FALSE
)
Value
An interactive visNetwork object with highlighting of connected nodes,
node selection and filtering by module, directional arrows, hierarchical
layout, and draggable nodes.
Arguments
- mcmodule
(mcmodule object). Module containing network to visualise.
- variate
(integer). Which variate to visualise. Default: 1.
- color_pal
(character vector, optional). Custom colour palette for nodes.
Default: NULL.
- color_by
(character, optional). Column name to determine node colours.
Default: NULL.
- legend
(logical). If TRUE, show colours legend. Default: FALSE.
- inputs
(logical). If TRUE, show non-node inputs. Default: FALSE.
Examples
Run this code# \donttest{
network <- mc_network(mcmodule=imports_mcmodule)
# }
Run the code above in your browser using DataLab