Learn R Programming

mcmodule (version 1.2.0)

set_data_keys: Set or Get Global Data Keys

Description

Manages a global data model by setting or retrieving data keys. The data model defines column names and their associated grouping keys for each data frame.

Usage

set_data_keys(data_keys = NULL)

Value

Current or newly set global data model (invisibly).

Arguments

data_keys

(list, optional). List of data specifications. Each element is a named list with:

  • cols: Character vector of column names.

  • keys: Character vector of key columns (subset of cols).

If NULL, returns the current global data model. Default: NULL.

Examples

Run this code
print(imports_data_keys)
set_data_keys(imports_data_keys)

Run the code above in your browser using DataLab